Enum ParserShowGrantsTarget
Source pub enum ParserShowGrantsTarget {
Table(String),
ApiKey(String),
}
Parsed SHOW GRANTS target
SHOW GRANTS ON
SHOW GRANTS FOR ‘<api_key_id>’
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Converts
self into
T using
Into<T>.
Read more
Causes self to use its Binary implementation when Debug-formatted.
Causes self to use its Display implementation when
Debug-formatted.
Causes self to use its LowerExp implementation when
Debug-formatted.
Causes self to use its LowerHex implementation when
Debug-formatted.
Causes self to use its Octal implementation when Debug-formatted.
Causes self to use its Pointer implementation when
Debug-formatted.
Causes self to use its UpperExp implementation when
Debug-formatted.
Causes self to use its UpperHex implementation when
Debug-formatted.
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
Pipes by value. This is generally the method you want to use.
Read more
Borrows
self and passes that borrow into the pipe function.
Read more
Mutably borrows
self and passes that borrow into the pipe function.
Read more
Borrows
self, then passes
self.borrow() into the pipe function.
Read more
Mutably borrows
self, then passes
self.borrow_mut() into the pipe
function.
Read more
Borrows self, then passes self.as_ref() into the pipe function.
Mutably borrows self, then passes self.as_mut() into the pipe
function.
Borrows self, then passes self.deref() into the pipe function.
Mutably borrows self, then passes self.deref_mut() into the pipe
function.
Immutable access to the
Borrow<B> of a value.
Read more
Mutable access to the
BorrowMut<B> of a value.
Read more
Immutable access to the
AsRef<R> view of a value.
Read more
Mutable access to the
AsMut<R> view of a value.
Read more
Immutable access to the
Deref::Target of a value.
Read more
Mutable access to the
Deref::Target of a value.
Read more
Calls .tap() only in debug builds, and is erased in release builds.
Calls .tap_mut() only in debug builds, and is erased in release
builds.
Calls .tap_borrow() only in debug builds, and is erased in release
builds.
Calls .tap_borrow_mut() only in debug builds, and is erased in release
builds.
Calls .tap_ref() only in debug builds, and is erased in release
builds.
Calls .tap_ref_mut() only in debug builds, and is erased in release
builds.
Calls .tap_deref() only in debug builds, and is erased in release
builds.
Calls .tap_deref_mut() only in debug builds, and is erased in release
builds.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
Attempts to convert
self into
T using
TryInto<T>.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.