Parser

Struct Parser 

pub struct Parser;
SQL parser wrapper with enhanced error messages

Implementations

Source

impl Parser

pub fn parse(sql: &str) -> Result<Vec<Statement>>

Parse a SQL string into statements with rich error context

pub fn parse_one(sql: &str) -> Result<Statement>

Parse a single statement with rich error context

pub fn parse_extended(sql: &str) -> Result<ParseResult>

Parse a statement with support for custom FeatherDB extensions

This handles statements like SHOW GRANTS that sqlparser doesn’t support.

pub fn parse_to_plan( sql: &str, catalog: &Catalog, ) -> Result<(LogicalPlan, HashMap<usize, LogicalPlan>)>

Parse SQL and convert to LogicalPlan, handling custom FeatherDB statements

This is the unified entry point that handles both standard SQL statements (via the Planner) and custom FeatherDB extensions (like SHOW GRANTS). Returns the plan and any subquery plans collected during planning.

pub fn is_custom_read_only(stmt: &CustomStatement) -> bool

Check if a SQL statement is read-only (for custom statements)

Returns true for SELECT, SHOW, EXPLAIN, etc.

pub fn convert_data_type(data_type: &DataType) -> Result<ColumnType>

Convert SQL data type to FeatherDB column type

pub fn parse_alter_table_ops( table_name: &ObjectName, operations: &[AlterTableOperation], ) -> Result<(String, Vec<AlterTableOp>)>

Parse ALTER TABLE operations from an AlterTable statement

pub fn parse_foreign_key_constraint( constraint: &TableConstraint, ) -> Result<Option<ForeignKey>>

Parse foreign key constraints from table-level constraints

Handles syntax like:

FOREIGN KEY (user_id) REFERENCES users(id) ON DELETE CASCADE
CONSTRAINT fk_name FOREIGN KEY (col1, col2) REFERENCES other(a, b)
pub fn parse_inline_foreign_key( column_name: &str, options: &[ColumnOptionDef], ) -> Result<Option<ForeignKey>>

Parse inline foreign key reference from column options

Handles syntax like:

user_id INTEGER REFERENCES users(id) ON DELETE CASCADE
pub fn parse_create_table_foreign_keys( columns: &[ColumnDef], constraints: &[TableConstraint], ) -> Result<Vec<ForeignKey>>

Parse all foreign keys from a CREATE TABLE statement

Returns a vector of ForeignKey constraints found in both:

  • Table-level FOREIGN KEY constraints
  • Inline REFERENCES clauses on columns